# NOT RUN {
## example: iris dataset
## load the package forestRK
library(forestRK)
## Basic Procedures:
## 1. Extract the portion of the data that stores class type of each
## TRAINING observation, and make it as a vector
## 2. apply y.organizer function to the vector obtained from 1
y.train <- y.organizer(as.vector(iris[c(1:25,51:75,101:125),5]))
## retrieves the original names of each class type, if the class names
## were originally non-numeric
y.train$y.factor.levels
## retrieves the numericized vector that stores classification category
y.train$y.new
# }
Run the code above in your browser using DataLab